@@ -1,4 +1,4 @@
-test_that("Q from inst/extdata equals Q from data/ ",{
+test_that("Q from inst/extdata equals Q from data/ ", {
   Q_file <- system.file("extdata", "Q.csv", package = "hydropeak")
   Q_file <- read.csv(Q_file)
   Q_file$ID <- as.character(Q_file$ID)
@@ -7,8 +7,9 @@ test_that("Q from inst/extdata equals Q from data/ ",{
   expect_equal(Q_file, Q)
 })
 
-test_that("Events from inst/extdata equals Events from data/ ",{
-  Events_file <- system.file("extdata", "Events.csv", package = "hydropeak")
+test_that("Events from inst/extdata equals Events from data/ ", {
+  Events_file <-
+    system.file("extdata", "Events.csv", package = "hydropeak")
   Events_file <- read.csv(Events_file)
   Events_file$ID <- as.character(Events_file$ID)
 
@@ -16,7 +17,8 @@ test_that("Events from inst/extdata equals Events from data/ ",{
   Events_file$Time <- as.POSIXct(Events_file$Time, tz = tz)
 
   # coerce row names to character
-  attr(Events_file, "row.names") <- as.character(attr(Events_file, "row.names"))
+  attr(Events_file, "row.names") <-
+    as.character(attr(Events_file, "row.names"))
 
   data(Events)
   expect_equal(Events_file, Events)
